@@ -4,45 +4,46 @@ import gzip
 from io import BytesIO
 from socket import timeout as sockettimeout
 from urllib.error import HTTPError, URLError
-from urllib.parse import urlencode
 from urllib.request import Request, urlopen
 
 from .exceptions import MeteoAlarmServiceError
 
-__version__ = "0.2.5"
+__version__: str = "1.0.5"
 
 
-UA = "meteoalarm-rssapi/{version} (gzip)".format(version=__version__)
-TIMEOUT = 20
+UA = f"meteoalarm-rssapi/{__version__} (gzip)"
+TIMEOUT: float = 20.0  # seconds
 
 
-class WEBQuery(object):
+class WEBQuery:
     """Class to query web services."""
 
-    def __init__(self, url, timeout=TIMEOUT):
+    def __init__(self, url: str, timeout: float = TIMEOUT) -> None:
         if not url.lower().startswith("http"):
-            raise MeteoAlarmServiceError("Url (%s) not allowed!" % url)
+            raise MeteoAlarmServiceError(f"Url ({url}) not allowed!")
         self._url = url
         self._timeout = timeout
         headers = {"Accept-Encoding": "gzip", "User-Agent": UA}
         self._request = Request(url, headers=headers)
 
     def response(self):
+        """Handle response and errors."""
         try:
             response = urlopen(self._request, timeout=self._timeout)
+            return response
         except HTTPError as e:
-            raise MeteoAlarmServiceError("(%s) %s" % (e.code, e.msg))
+            raise MeteoAlarmServiceError(f"({e.code}) {e.msg}")
         except URLError as e:
             raise MeteoAlarmServiceError(e.reason)
         except sockettimeout:
             raise MeteoAlarmServiceError("service timeout")
         except TypeError:
             raise MeteoAlarmServiceError("service bad response")
-        return response if response else None
 
-    def data(self):
+    def data(self) -> bytes:
         """Return the uncompressed data."""
         res = self.response()
+        data: bytes
         if res.info().get("Content-Encoding") == "gzip":
             buf = BytesIO(res.read())
             f = gzip.GzipFile(fileobj=buf)
@@ -52,6 +53,7 @@ class WEBQuery(object):
         return data
 
 
-def query(url, timeout=TIMEOUT):
+def query(url: str, timeout: float = TIMEOUT) -> bytes:
+    """Interface function to class WEBQuery."""
     service = WEBQuery(url, timeout)
     return service.data()
